aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/tools/ci_build
diff options
context:
space:
mode:
authorGravatar Austin Anderson <angerson@google.com>2018-09-06 18:59:39 -0700
committerGravatar TensorFlower Gardener <gardener@tensorflow.org>2018-09-06 19:03:13 -0700
commit95607ef71ff6acf4b091c18b9a67c9644aa4ac2d (patch)
tree24f093f18201e13a31c4ca7dbddd99e51c6bf0d4 /tensorflow/tools/ci_build
parented7dcd42076afe778e3ead8f86708cabd4e8ce10 (diff)
Add TF Lite-disabling variable
PiperOrigin-RevId: 211906579
Diffstat (limited to 'tensorflow/tools/ci_build')
-rwxr-xr-xtensorflow/tools/ci_build/ci_parameterized_build.sh13
1 files changed, 9 insertions, 4 deletions
diff --git a/tensorflow/tools/ci_build/ci_parameterized_build.sh b/tensorflow/tools/ci_build/ci_parameterized_build.sh
index 1d7d9df72f..be7099e7c0 100755
--- a/tensorflow/tools/ci_build/ci_parameterized_build.sh
+++ b/tensorflow/tools/ci_build/ci_parameterized_build.sh
@@ -85,8 +85,11 @@
# Use the specified configurations when building.
# When set, overrides TF_BUILD_IS_OPT and TF_BUILD_MAVX
# options, as this will replace the two.
+# TF_SKIP_LITE_TESTS:
+# If set to any non-empty or non-0 value, will skip running
+# contrib/lite tests, but will leave other contrib tests.
# TF_SKIP_CONTRIB_TESTS:
# If set to any non-empty or non-0 value, will skipp running
# contrib tests.
# TF_NIGHTLY:
# If this run is being used to build the tf_nightly pip
@@ -147,10 +150,12 @@ BENCHMARK_CMD="${CI_BUILD_DIR}/builds/benchmark.sh"
EXTRA_PARAMS=""
BAZEL_TARGET="//tensorflow/... -//tensorflow/compiler/..."
+if [[ -n "$TF_SKIP_LITE_TESTS" ]]; then
+ BAZEL_TARGET="${BAZEL_TARGET} -//tensorflow/contrib/lite/..."
+fi
+
if [[ -n "$TF_SKIP_CONTRIB_TESTS" ]]; then
- BAZEL_TARGET="$BAZEL_TARGET -//tensorflow/contrib/..."
-else
- BAZEL_TARGET="${BAZEL_TARGET} //tensorflow/contrib/lite/..."
+ BAZEL_TARGET="${BAZEL_TARGET} -//tensorflow/contrib/..."
fi
TUT_TEST_DATA_DIR="/tmp/tf_tutorial_test_data"
@@ -85,8 +85,11 @@
# TF_SKIP_CONTRIB_TESTS:
-# If set to any non-empty or non-0 value, will skipp running
+# If set to any non-empty or non-0 value, will skip running
# contrib tests.
# TF_NIGHTLY: